@@ -4,13 +4,13 @@
 
 source ./DefConf.inc
 
-DOCFILES="COPYING ChangeLog README TODO sample_monthly sample_rc"
+DOCFILES="COPYING ChangeLog README INSTALL TODO sample_monthly sample_rc"
 
 echo "install script for Rot[t]Log v.$VERSION"
 echo
 echo "Updating bash codes..."
 
-esc_MAINPATH=${MAINPATH//\//\\/}
+esc_MAINPATH=${ROTT_ETCDIR//\//\\/}
 sed -e 's/^MAINPATH=.*/MAINPATH=\"$esc_MAINPATH\"/' rottlog >newrottlog
 if [ ! -s newrottlog ]; then
   echo "Error using sed to modify rottlog!!"
@@ -49,5 +49,5 @@ for D in $DOCFILES; do
 done
 
 mkdir -p $ROTT_ETCDIR
-chmod 0300 ROTT_ETCDIR
+chmod 0300 $ROTT_ETCDIR
 
